@@ -143,37 +143,14 @@ G_DEFINE_TYPE(VipsComplex, vips_complex, VIPS_TYPE_UNARY);
 		g_assert_not_reached(); \
 	}
 
-static double
-vips_complex_hypot(double a, double b)
-{
-	double d;
-
-	/* hypot() is less sensitive to overflow. Use it if we can.
-	 */
-#ifdef HAVE_HYPOT
-	d = hypot(a, b);
-#else
-	d = sqrt(a * a + b * b);
-#endif
-
-	return d;
-}
-
 static double
 vips_complex_atan2(double a, double b)
 {
 	double h;
 
-	/* atan2() is very slow, but is better behaved when a is near 0. Use
-	 * it in preference when we can.
-	 */
-#ifdef HAVE_ATAN2
 	h = VIPS_DEG(atan2(b, a));
 	if (h < 0.0)
 		h += 360;
-#else
-	h = vips_col_ab2h(a, b);
-#endif
 
 	return h;
 }
@@ -184,7 +161,7 @@ vips_complex_atan2(double a, double b)
 		double im = (Y); \
 		double am, ph; \
 \
-		am = vips_complex_hypot(re, im); \
+		am = hypot(re, im); \
 		ph = vips_complex_atan2(re, im); \
 \
 		Q[0] = am; \
@@ -469,34 +446,6 @@ G_DEFINE_TYPE(VipsComplex2, vips_complex2, VIPS_TYPE_BINARY);
 		g_assert_not_reached(); \
 	}
 
-/* There doesn't seem to be much difference in speed between these two methods
- * (on an Athlon64), so I use the modulus argument version, since atan2() is
- * in c89 but hypot() is c99.
- *
- * If you think that it might be faster on your platform, uncomment the
- * following:
- */
-#define USE_MODARG_DIV
-
-#ifdef USE_MODARG_DIV
-
-#define CROSS(Q, X1, Y1, X2, Y2) \
-	{ \
-		if (((X1) == 0.0 && (Y1) == 0.0) || \
-			((X2) == 0.0 && (Y2) == 0.0)) { \
-			Q[0] = 0.0; \
-			Q[1] = 0.0; \
-		} \
-		else { \
-			double arg = atan2(X2, X1) - atan2(Y2, Y1); \
-\
-			Q[0] = cos(arg); \
-			Q[1] = sin(arg); \
-		} \
-	}
-
-#else /* USE_MODARG_DIV */
-
 #define CROSS(Q, X1, Y1, X2, Y2) \
 	{ \
 		if (((X1) == 0.0 && (Y1) == 0.0) || \
@@ -509,7 +458,7 @@ G_DEFINE_TYPE(VipsComplex2, vips_complex2, VIPS_TYPE_BINARY);
 			double b = Y1 + Y2 * a; \
 			double re = (X1 + X2 * a) / b; \
 			double im = (X2 - X1 * a) / b; \
-			double mod = vips__hypot(re, im); \
+			double mod = hypot(re, im); \
 \
 			Q[0] = re / mod; \
 			Q[1] = im / mod; \
@@ -519,15 +468,13 @@ G_DEFINE_TYPE(VipsComplex2, vips_complex2, VIPS_TYPE_BINARY);
 			double b = Y2 + Y1 * a; \
 			double re = (X1 * a + X2) / b; \
 			double im = (X2 * a - X1) / b; \
-			double mod = vips__hypot(re, im); \
+			double mod = hypot(re, im); \
 \
 			Q[0] = re / mod; \
 			Q[1] = im / mod; \
 		} \
 	}
 
-#endif /* USE_MODARG_DIV */
-
 static void
 vips_complex2_buffer(VipsArithmetic *arithmetic,
 	VipsPel *out, VipsPel **in, int width)
