@@ -583,7 +583,7 @@ vips_composite_base_blend(VipsCompositeBase *composite,
 
 	case VIPS_BLEND_MODE_DEST_ATOP:
 		aR = aA;
-		t1 = 1 - aA;
+		t1 = 1 - aB;
 		for (int b = 0; b < bands; b++)
 			B[b] = t1 * A[b] + B[b];
 		break;
@@ -827,7 +827,7 @@ vips_composite_base_blend3(VipsCompositeSequence *seq,
 
 	case VIPS_BLEND_MODE_DEST_ATOP:
 		aR = aA;
-		t1 = 1 - aA;
+		t1 = 1 - aB;
 		B = t1 * A + B;
 		break;
 
@@ -1537,8 +1537,7 @@ vips_composite_build(VipsObject *object)
 
 	if (vips_object_argument_isset(object, "x")) {
 		if (composite->x->area.n != n - 1) {
-			vips_error(klass->nickname,
-				_("must be %d x coordinates"), n - 1);
+			vips_error(klass->nickname, _("must be %d x coordinates"), n - 1);
 			return -1;
 		}
 		base->x_offset = (int *) composite->x->area.data;
@@ -1546,8 +1545,7 @@ vips_composite_build(VipsObject *object)
 
 	if (vips_object_argument_isset(object, "y")) {
 		if (composite->y->area.n != n - 1) {
-			vips_error(klass->nickname,
-				_("must be %d y coordinates"), n - 1);
+			vips_error(klass->nickname, _("must be %d y coordinates"), n - 1);
 			return -1;
 		}
 		base->y_offset = (int *) composite->y->area.data;
