@@ -235,8 +235,7 @@ vips_text_get_extents(VipsText *text, VipsRect *extents)
 			  text->justify)))
 		return -1;
 
-	pango_layout_get_pixel_extents(text->layout,
-		&ink_rect, &logical_rect);
+	pango_layout_get_pixel_extents(text->layout, &ink_rect, &logical_rect);
 	extents->left = ink_rect.x;
 	extents->top = ink_rect.y;
 	extents->width = ink_rect.width;
@@ -395,7 +394,7 @@ vips_text_build(VipsObject *object)
 	VipsImage **t = (VipsImage **) vips_object_local_array(object, 3);
 
 	VipsRect extents;
-	VipsImage *image;
+	VipsImage *in;
 	cairo_surface_t *surface;
 	cairo_t *cr;
 	cairo_status_t status;
@@ -471,26 +470,26 @@ vips_text_build(VipsObject *object)
 		return -1;
 	}
 
-	image = t[0] = vips_image_new_memory();
-	vips_image_init_fields(image,
+	t[0] = vips_image_new_memory();
+	vips_image_init_fields(t[0],
 		extents.width, extents.height, 4,
-		VIPS_FORMAT_UCHAR, VIPS_CODING_NONE,
-		VIPS_INTERPRETATION_sRGB,
+		VIPS_FORMAT_UCHAR, VIPS_CODING_NONE, VIPS_INTERPRETATION_sRGB,
 		text->dpi / 25.4, text->dpi / 25.4);
-	image->Xoffset = extents.left;
-	image->Yoffset = extents.top;
+	t[0]->Xoffset = extents.left;
+	t[0]->Yoffset = extents.top;
 
-	if (vips_image_pipelinev(image, VIPS_DEMAND_STYLE_ANY, NULL) ||
-		vips_image_write_prepare(image)) {
+	if (vips_image_pipelinev(t[0], VIPS_DEMAND_STYLE_ANY, NULL) ||
+		vips_image_write_prepare(t[0])) {
 		g_mutex_unlock(vips_text_lock);
 		return -1;
 	}
+	in = t[0];
 
 	surface = cairo_image_surface_create_for_data(
-		VIPS_IMAGE_ADDR(image, 0, 0),
+		VIPS_IMAGE_ADDR(in, 0, 0),
 		CAIRO_FORMAT_ARGB32,
-		image->Xsize, image->Ysize,
-		VIPS_IMAGE_SIZEOF_LINE(image));
+		in->Xsize, in->Ysize,
+		VIPS_IMAGE_SIZEOF_LINE(in));
 
 	status = cairo_surface_status(surface);
 	if (status) {
@@ -513,29 +512,26 @@ vips_text_build(VipsObject *object)
 	g_mutex_unlock(vips_text_lock);
 
 	if (text->rgba) {
-		int y;
-
 		/* Cairo makes pre-multipled BRGA -- we must byteswap and
 		 * unpremultiply.
 		 */
-		for (y = 0; y < image->Ysize; y++)
+		for (int y = 0; y < in->Ysize; y++)
 			vips__premultiplied_bgra2rgba(
-				(guint32 *)
-					VIPS_IMAGE_ADDR(image, 0, y),
-				image->Xsize);
+				(guint32 *) VIPS_IMAGE_ADDR(in, 0, y),
+				in->Xsize);
 	}
 	else {
 		/* We just want the alpha channel.
 		 */
-		if (vips_extract_band(image, &t[1], 3, NULL) ||
+		if (vips_extract_band(in, &t[1], 3, NULL) ||
 			vips_copy(t[1], &t[2],
 				"interpretation", VIPS_INTERPRETATION_MULTIBAND,
 				NULL))
 			return -1;
-		image = t[2];
+		in = t[2];
 	}
 
-	if (vips_image_write(image, create->out))
+	if (vips_image_write(in, create->out))
 		return -1;
 
 	return 0;
