@@ -566,18 +566,17 @@ pyramid_build(VipsForeignSaveDz *dz,
 static int
 write_dzi(VipsForeignSaveDz *dz)
 {
-	VipsDbuf dbuf;
+	VipsDbuf dbuf = { 0 };
+
 	char filename[VIPS_PATH_MAX];
 	char format[VIPS_PATH_MAX];
 	char *p;
 	void *buf;
 	size_t len;
 
-	vips_snprintf(filename, VIPS_PATH_MAX, "%s.dzi", dz->imagename);
+	g_snprintf(filename, VIPS_PATH_MAX, "%s.dzi", dz->imagename);
 
-	vips_dbuf_init(&dbuf);
-
-	vips_snprintf(format, VIPS_PATH_MAX, "%s", dz->suffix + 1);
+	g_snprintf(format, VIPS_PATH_MAX, "%s", dz->suffix + 1);
 	if ((p = (char *) vips__find_rightmost_brackets(format)))
 		*p = '\0';
 
@@ -610,15 +609,14 @@ write_dzi(VipsForeignSaveDz *dz)
 static int
 write_properties(VipsForeignSaveDz *dz)
 {
-	VipsDbuf dbuf;
+	VipsDbuf dbuf = { 0 };
+
 	char *filename;
 	void *buf;
 	size_t len;
 
 	filename = g_build_filename(dz->root_name, "ImageProperties.xml", NULL);
 
-	vips_dbuf_init(&dbuf);
-
 	vips_dbuf_writef(&dbuf, "<IMAGE_PROPERTIES "
 							"WIDTH=\"%d\" HEIGHT=\"%d\" NUMTILES=\"%d\" "
 							"NUMIMAGES=\"1\" VERSION=\"1.8\" "
@@ -700,13 +698,14 @@ write_blank(VipsForeignSaveDz *dz)
 static int
 write_json(VipsForeignSaveDz *dz)
 {
+	VipsDbuf dbuf = { 0 };
+
 	/* dz->file_suffix has a leading "." character.
 	 */
 	const char *suffix = dz->file_suffix[0] == '.'
 		? dz->file_suffix + 1
 		: dz->file_suffix;
 
-	VipsDbuf dbuf;
 	char *filename;
 	void *buf;
 	size_t len;
@@ -714,8 +713,6 @@ write_json(VipsForeignSaveDz *dz)
 
 	filename = g_build_filename(dz->root_name, "info.json", NULL);
 
-	vips_dbuf_init(&dbuf);
-
 	if (dz->layout == VIPS_FOREIGN_DZ_LAYOUT_IIIF3)
 		vips_dbuf_writef(&dbuf,
 			"{\n"
@@ -808,6 +805,7 @@ write_json(VipsForeignSaveDz *dz)
 		if (vips__archive_mkfile(dz->archive, filename, buf, len)) {
 			g_free(filename);
 			g_free(buf);
+
 			return -1;
 		}
 
@@ -919,13 +917,12 @@ static char *scan_property_names[][2] = {
 static char *
 build_scan_properties(VipsImage *image, size_t *len)
 {
-	VipsDbuf dbuf;
+	VipsDbuf dbuf = { 0 };
 	char *date;
 	int i;
 
 	date = vips__get_iso8601();
 
-	vips_dbuf_init(&dbuf);
 	vips_dbuf_writef(&dbuf, "<?xml version=\"1.0\"?>\n");
 	vips_dbuf_writef(&dbuf,
 		"<image xmlns=\"http://www.pathozoom.com/szi\""
@@ -993,7 +990,7 @@ write_associated_images(VipsImage *image,
 		if (vips__archive_mkdir(dz->archive, "associated_images"))
 			return image;
 
-		vips_snprintf(buf, VIPS_PATH_MAX, "%s.jpg", p);
+		g_snprintf(buf, VIPS_PATH_MAX, "%s.jpg", p);
 
 		out = g_build_filename("associated_images", buf, NULL);
 
@@ -1157,8 +1154,8 @@ tile_name(Level *level, int x, int y)
 
 	switch (dz->layout) {
 	case VIPS_FOREIGN_DZ_LAYOUT_DZ:
-		vips_snprintf(subdir, VIPS_PATH_MAX, "%d", level->n);
-		vips_snprintf(name, VIPS_PATH_MAX, "%d_%d%s", x, y, dz->file_suffix);
+		g_snprintf(subdir, VIPS_PATH_MAX, "%d", level->n);
+		g_snprintf(name, VIPS_PATH_MAX, "%d_%d%s", x, y, dz->file_suffix);
 
 		break;
 
@@ -1179,8 +1176,8 @@ tile_name(Level *level, int x, int y)
 		 */
 		n += y * level->tiles_across + x;
 
-		vips_snprintf(subdir, VIPS_PATH_MAX, "TileGroup%d", n / 256);
-		vips_snprintf(name, VIPS_PATH_MAX,
+		g_snprintf(subdir, VIPS_PATH_MAX, "TileGroup%d", n / 256);
+		g_snprintf(name, VIPS_PATH_MAX,
 			"%d-%d-%d%s", level->n, x, y, dz->file_suffix);
 
 		/* Used at the end in ImageProperties.xml
@@ -1190,9 +1187,9 @@ tile_name(Level *level, int x, int y)
 		break;
 
 	case VIPS_FOREIGN_DZ_LAYOUT_GOOGLE:
-		vips_snprintf(subdir, VIPS_PATH_MAX,
+		g_snprintf(subdir, VIPS_PATH_MAX,
 			"%d" G_DIR_SEPARATOR_S "%d", level->n, y);
-		vips_snprintf(name, VIPS_PATH_MAX,
+		g_snprintf(name, VIPS_PATH_MAX,
 			"%d%s", x, dz->file_suffix);
 
 		break;
@@ -1225,7 +1222,7 @@ tile_name(Level *level, int x, int y)
 			int ysize = VIPS_MIN(dz->tile_size,
 				level->height - y * dz->tile_size);
 
-			vips_snprintf(subdir, VIPS_PATH_MAX,
+			g_snprintf(subdir, VIPS_PATH_MAX,
 				"%d,%d,%d,%d" G_DIR_SEPARATOR_S "%d,%d" G_DIR_SEPARATOR_S "%d",
 				left, top, width, height,
 				xsize, ysize,
@@ -1237,14 +1234,14 @@ tile_name(Level *level, int x, int y)
 			int size = VIPS_MIN(dz->tile_size,
 				level->width - x * dz->tile_size);
 
-			vips_snprintf(subdir, VIPS_PATH_MAX,
+			g_snprintf(subdir, VIPS_PATH_MAX,
 				"%d,%d,%d,%d" G_DIR_SEPARATOR_S "%d," G_DIR_SEPARATOR_S "%d",
 				left, top, width, height,
 				size,
 				rotation);
 		}
 
-		vips_snprintf(name, VIPS_PATH_MAX, "default%s", dz->file_suffix);
+		g_snprintf(name, VIPS_PATH_MAX, "default%s", dz->file_suffix);
 	}
 
 	break;
@@ -1930,6 +1927,15 @@ pyramid_strip(VipsRegion *region, VipsRect *area, void *a)
 	return 0;
 }
 
+#define UC VIPS_FORMAT_UCHAR
+
+/* We force all types to uchar for save.
+ */
+static VipsBandFormat bandfmt_dzsave[10] = {
+	/* Band format:  UC  C   US  S   UI  I   F   X   D   DX */
+	/* Promotion: */ UC, UC, UC, UC, UC, UC, UC, UC, UC, UC
+};
+
 static int
 vips_foreign_save_dz_build(VipsObject *object)
 {
@@ -2050,6 +2056,26 @@ vips_foreign_save_dz_build(VipsObject *object)
 		save->ready = z;
 	}
 
+	/* If we're saving to direct JPEG we need to convert to 8-bit
+	 * RGB | mono | cmyk.
+	 */
+	if (dz->direct) {
+		VipsImage *z;
+		gboolean coding[VIPS_CODING_LAST];
+
+		for (int i = 0; i < VIPS_CODING_LAST; i++)
+			coding[i] = FALSE;
+		coding[VIPS_CODING_NONE] = TRUE;
+
+		if (vips__foreign_convert_saveable(save->ready, &z,
+			VIPS_SAVEABLE_RGB_CMYK, bandfmt_dzsave, coding,
+			save->background))
+			return -1;
+
+		VIPS_UNREF(save->ready);
+		save->ready = z;
+	}
+
 	/* We use ink to check for blank tiles.
 	 */
 	if (dz->skip_blanks >= 0) {
@@ -2073,7 +2099,6 @@ vips_foreign_save_dz_build(VipsObject *object)
 	 * again.
 	 */
 	if (dz->layout == VIPS_FOREIGN_DZ_LAYOUT_GOOGLE) {
-
 		VipsImage *z;
 		Level *level;
 		Level *p;
