@@ -1058,7 +1058,7 @@ vips_foreign_save_jp2k_file_class_init(VipsForeignSaveJp2kFileClass *class)
 
 	VIPS_ARG_STRING(class, "filename", 1,
 		_("Filename"),
-		_("Filename to load from"),
+		_("Filename to save to"),
 		VIPS_ARGUMENT_REQUIRED_INPUT,
 		G_STRUCT_OFFSET(VipsForeignSaveJp2kFile, filename),
 		NULL);
