@@ -8,28 +8,28 @@
 
 /*
 
-    This file is part of VIPS.
-    
-    VIPS is free software; you can redistribute it and/or modify
-    it under the terms of the GNU Lesser General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
+	This file is part of VIPS.
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU Lesser General Public License for more details.
+	VIPS is free software; you can redistribute it and/or modify
+	it under the terms of the GNU Lesser General Public License as published by
+	the Free Software Foundation; either version 2 of the License, or
+	(at your option) any later version.
 
-    You should have received a copy of the GNU Lesser General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301  USA
+	This program is distributed in the hope that it will be useful,
+	but WITHOUT ANY WARRANTY; without even the implied warranty of
+	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+	GNU Lesser General Public License for more details.
+
+	You should have received a copy of the GNU Lesser General Public License
+	along with this program; if not, write to the Free Software
+	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+	02110-1301  USA
 
  */
 
 /*
 
-    These files are distributed with VIPS - http://www.vips.ecs.soton.ac.uk
+	These files are distributed with VIPS - http://www.vips.ecs.soton.ac.uk
 
  */
 
@@ -40,7 +40,7 @@
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif /*HAVE_CONFIG_H*/
-#include <vips/intl.h>
+#include <glib/gi18n-lib.h>
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -52,7 +52,7 @@
 
 #include "pforeign.h"
 
-#if defined(HAVE_PNG) && !defined(HAVE_SPNG)
+#if defined(HAVE_PNG)
 
 typedef struct _VipsForeignLoadPng {
 	VipsForeignLoad parent_object;
@@ -69,83 +69,82 @@ typedef struct _VipsForeignLoadPng {
 
 typedef VipsForeignLoadClass VipsForeignLoadPngClass;
 
-G_DEFINE_ABSTRACT_TYPE( VipsForeignLoadPng, vips_foreign_load_png, 
-	VIPS_TYPE_FOREIGN_LOAD );
+G_DEFINE_ABSTRACT_TYPE(VipsForeignLoadPng, vips_foreign_load_png,
+	VIPS_TYPE_FOREIGN_LOAD);
 
 static void
-vips_foreign_load_png_dispose( GObject *gobject )
+vips_foreign_load_png_dispose(GObject *gobject)
 {
 	VipsForeignLoadPng *png = (VipsForeignLoadPng *) gobject;
 
-	VIPS_UNREF( png->source );
+	VIPS_UNREF(png->source);
 
-	G_OBJECT_CLASS( vips_foreign_load_png_parent_class )->
-		dispose( gobject );
+	G_OBJECT_CLASS(vips_foreign_load_png_parent_class)->dispose(gobject);
 }
 
 static VipsForeignFlags
-vips_foreign_load_png_get_flags_source( VipsSource *source )
+vips_foreign_load_png_get_flags_source(VipsSource *source)
 {
 	VipsForeignFlags flags;
 
 	flags = 0;
-	if( vips__png_isinterlaced_source( source ) )
+	if (vips__png_isinterlaced_source(source))
 		flags |= VIPS_FOREIGN_PARTIAL;
 	else
 		flags |= VIPS_FOREIGN_SEQUENTIAL;
 
-	return( flags );
+	return flags;
 }
 
 static VipsForeignFlags
-vips_foreign_load_png_get_flags( VipsForeignLoad *load )
+vips_foreign_load_png_get_flags(VipsForeignLoad *load)
 {
 	VipsForeignLoadPng *png = (VipsForeignLoadPng *) load;
 
-	return( vips_foreign_load_png_get_flags_source( png->source ) );
+	return vips_foreign_load_png_get_flags_source(png->source);
 }
 
 static VipsForeignFlags
-vips_foreign_load_png_get_flags_filename( const char *filename )
+vips_foreign_load_png_get_flags_filename(const char *filename)
 {
 	VipsSource *source;
 	VipsForeignFlags flags;
 
-	if( !(source = vips_source_new_from_file( filename )) )
-		return( 0 );
-	flags = vips_foreign_load_png_get_flags_source( source );
-	VIPS_UNREF( source );
+	if (!(source = vips_source_new_from_file(filename)))
+		return 0;
+	flags = vips_foreign_load_png_get_flags_source(source);
+	VIPS_UNREF(source);
 
-	return( flags );
+	return flags;
 }
 
 static int
-vips_foreign_load_png_header( VipsForeignLoad *load )
+vips_foreign_load_png_header(VipsForeignLoad *load)
 {
 	VipsForeignLoadPng *png = (VipsForeignLoadPng *) load;
 
-	if( vips__png_header_source( png->source, load->out, png->unlimited ) )
-		return( -1 );
+	if (vips__png_header_source(png->source, load->out, png->unlimited))
+		return -1;
 
-	return( 0 );
+	return 0;
 }
 
 static int
-vips_foreign_load_png_load( VipsForeignLoad *load )
+vips_foreign_load_png_load(VipsForeignLoad *load)
 {
 	VipsForeignLoadPng *png = (VipsForeignLoadPng *) load;
 
-	if( vips__png_read_source( png->source, load->real, 
-		load->fail_on, png->unlimited ) )
-		return( -1 );
+	if (vips__png_read_source(png->source, load->real,
+			load->fail_on, png->unlimited))
+		return -1;
 
-	return( 0 );
+	return 0;
 }
 
 static void
-vips_foreign_load_png_class_init( VipsForeignLoadPngClass *class )
+vips_foreign_load_png_class_init(VipsForeignLoadPngClass *class)
 {
-	GObjectClass *gobject_class = G_OBJECT_CLASS( class );
+	GObjectClass *gobject_class = G_OBJECT_CLASS(class);
 	VipsObjectClass *object_class = (VipsObjectClass *) class;
 	VipsForeignClass *foreign_class = (VipsForeignClass *) class;
 	VipsForeignLoadClass *load_class = (VipsForeignLoadClass *) class;
@@ -155,28 +154,28 @@ vips_foreign_load_png_class_init( VipsForeignLoadPngClass *class )
 	gobject_class->get_property = vips_object_get_property;
 
 	object_class->nickname = "pngload_base";
-	object_class->description = _( "load png base class" );
+	object_class->description = _("load png base class");
 
 	/* We are fast at is_a(), so high priority.
 	 */
 	foreign_class->priority = 200;
 
-	load_class->get_flags_filename = 
+	load_class->get_flags_filename =
 		vips_foreign_load_png_get_flags_filename;
 	load_class->get_flags = vips_foreign_load_png_get_flags;
 	load_class->header = vips_foreign_load_png_header;
 	load_class->load = vips_foreign_load_png_load;
 
-	VIPS_ARG_BOOL( class, "unlimited", 23,
-		_( "Unlimited" ),
-		_( "Remove all denial of service limits" ),
+	VIPS_ARG_BOOL(class, "unlimited", 23,
+		_("Unlimited"),
+		_("Remove all denial of service limits"),
 		VIPS_ARGUMENT_OPTIONAL_INPUT,
-		G_STRUCT_OFFSET( VipsForeignLoadPng, unlimited ),
-		FALSE );
+		G_STRUCT_OFFSET(VipsForeignLoadPng, unlimited),
+		FALSE);
 }
 
 static void
-vips_foreign_load_png_init( VipsForeignLoadPng *png )
+vips_foreign_load_png_init(VipsForeignLoadPng *png)
 {
 }
 
@@ -191,63 +190,62 @@ typedef struct _VipsForeignLoadPngSource {
 
 typedef VipsForeignLoadPngClass VipsForeignLoadPngSourceClass;
 
-G_DEFINE_TYPE( VipsForeignLoadPngSource, vips_foreign_load_png_source, 
-	vips_foreign_load_png_get_type() );
+G_DEFINE_TYPE(VipsForeignLoadPngSource, vips_foreign_load_png_source,
+	vips_foreign_load_png_get_type());
 
 static int
-vips_foreign_load_png_source_build( VipsObject *object )
+vips_foreign_load_png_source_build(VipsObject *object)
 {
 	VipsForeignLoadPng *png = (VipsForeignLoadPng *) object;
 	VipsForeignLoadPngSource *source = (VipsForeignLoadPngSource *) object;
 
-	if( source->source ) {
+	if (source->source) {
 		png->source = source->source;
-		g_object_ref( png->source );
+		g_object_ref(png->source);
 	}
 
-	if( VIPS_OBJECT_CLASS( vips_foreign_load_png_source_parent_class )->
-		build( object ) )
-		return( -1 );
+	if (VIPS_OBJECT_CLASS(vips_foreign_load_png_source_parent_class)
+			->build(object))
+		return -1;
 
-	return( 0 );
+	return 0;
 }
 
 static gboolean
-vips_foreign_load_png_source_is_a_source( VipsSource *source )
+vips_foreign_load_png_source_is_a_source(VipsSource *source)
 {
-	return( vips__png_ispng_source( source ) );
+	return vips__png_ispng_source(source);
 }
 
 static void
-vips_foreign_load_png_source_class_init( VipsForeignLoadPngSourceClass *class )
+vips_foreign_load_png_source_class_init(VipsForeignLoadPngSourceClass *class)
 {
-	GObjectClass *gobject_class = G_OBJECT_CLASS( class );
+	GObjectClass *gobject_class = G_OBJECT_CLASS(class);
 	VipsObjectClass *object_class = (VipsObjectClass *) class;
-	VipsOperationClass *operation_class = VIPS_OPERATION_CLASS( class );
+	VipsOperationClass *operation_class = VIPS_OPERATION_CLASS(class);
 	VipsForeignLoadClass *load_class = (VipsForeignLoadClass *) class;
 
 	gobject_class->set_property = vips_object_set_property;
 	gobject_class->get_property = vips_object_get_property;
 
 	object_class->nickname = "pngload_source";
-	object_class->description = _( "load png from source" );
+	object_class->description = _("load png from source");
 	object_class->build = vips_foreign_load_png_source_build;
 
-	operation_class->flags = VIPS_OPERATION_NOCACHE;
+	operation_class->flags |= VIPS_OPERATION_NOCACHE;
 
 	load_class->is_a_source = vips_foreign_load_png_source_is_a_source;
 
-	VIPS_ARG_OBJECT( class, "source", 1,
-		_( "Source" ),
-		_( "Source to load from" ),
-		VIPS_ARGUMENT_REQUIRED_INPUT, 
-		G_STRUCT_OFFSET( VipsForeignLoadPngSource, source ),
-		VIPS_TYPE_SOURCE );
-
+	VIPS_ARG_OBJECT(class, "source", 1,
+		_("Source"),
+		_("Source to load from"),
+		VIPS_ARGUMENT_REQUIRED_INPUT,
+		G_STRUCT_OFFSET(VipsForeignLoadPngSource, source),
+		VIPS_TYPE_SOURCE);
 }
 
 static void
-vips_foreign_load_png_source_init( VipsForeignLoadPngSource *source )
+vips_foreign_load_png_source_init(VipsForeignLoadPngSource *source)
 {
 }
 
@@ -256,50 +254,49 @@ typedef struct _VipsForeignLoadPngFile {
 
 	/* Filename for load.
 	 */
-	char *filename; 
+	char *filename;
 
 } VipsForeignLoadPngFile;
 
 typedef VipsForeignLoadPngClass VipsForeignLoadPngFileClass;
 
-G_DEFINE_TYPE( VipsForeignLoadPngFile, vips_foreign_load_png_file, 
-	vips_foreign_load_png_get_type() );
+G_DEFINE_TYPE(VipsForeignLoadPngFile, vips_foreign_load_png_file,
+	vips_foreign_load_png_get_type());
 
 static int
-vips_foreign_load_png_file_build( VipsObject *object )
+vips_foreign_load_png_file_build(VipsObject *object)
 {
 	VipsForeignLoadPng *png = (VipsForeignLoadPng *) object;
 	VipsForeignLoadPngFile *file = (VipsForeignLoadPngFile *) object;
 
-	if( file->filename &&
-		!(png->source = vips_source_new_from_file( file->filename )) )
-		return( -1 );
+	if (file->filename &&
+		!(png->source = vips_source_new_from_file(file->filename)))
+		return -1;
 
-	if( VIPS_OBJECT_CLASS( vips_foreign_load_png_file_parent_class )->
-		build( object ) )
-		return( -1 );
+	if (VIPS_OBJECT_CLASS(vips_foreign_load_png_file_parent_class)->build(object))
+		return -1;
 
-	return( 0 );
+	return 0;
 }
 
 static gboolean
-vips_foreign_load_png_file_is_a( const char *filename )
+vips_foreign_load_png_file_is_a(const char *filename)
 {
 	VipsSource *source;
 	gboolean result;
 
-	if( !(source = vips_source_new_from_file( filename )) )
-		return( FALSE );
-	result = vips_foreign_load_png_source_is_a_source( source );
-	VIPS_UNREF( source );
+	if (!(source = vips_source_new_from_file(filename)))
+		return FALSE;
+	result = vips_foreign_load_png_source_is_a_source(source);
+	VIPS_UNREF(source);
 
-	return( result );
+	return result;
 }
 
 static void
-vips_foreign_load_png_file_class_init( VipsForeignLoadPngFileClass *class )
+vips_foreign_load_png_file_class_init(VipsForeignLoadPngFileClass *class)
 {
-	GObjectClass *gobject_class = G_OBJECT_CLASS( class );
+	GObjectClass *gobject_class = G_OBJECT_CLASS(class);
 	VipsObjectClass *object_class = (VipsObjectClass *) class;
 	VipsForeignClass *foreign_class = (VipsForeignClass *) class;
 	VipsForeignLoadClass *load_class = (VipsForeignLoadClass *) class;
@@ -308,23 +305,23 @@ vips_foreign_load_png_file_class_init( VipsForeignLoadPngFileClass *class )
 	gobject_class->get_property = vips_object_get_property;
 
 	object_class->nickname = "pngload";
-	object_class->description = _( "load png from file" );
+	object_class->description = _("load png from file");
 	object_class->build = vips_foreign_load_png_file_build;
 
 	foreign_class->suffs = vips__png_suffs;
 
 	load_class->is_a = vips_foreign_load_png_file_is_a;
 
-	VIPS_ARG_STRING( class, "filename", 1, 
-		_( "Filename" ),
-		_( "Filename to load from" ),
-		VIPS_ARGUMENT_REQUIRED_INPUT, 
-		G_STRUCT_OFFSET( VipsForeignLoadPngFile, filename ),
-		NULL );
+	VIPS_ARG_STRING(class, "filename", 1,
+		_("Filename"),
+		_("Filename to load from"),
+		VIPS_ARGUMENT_REQUIRED_INPUT,
+		G_STRUCT_OFFSET(VipsForeignLoadPngFile, filename),
+		NULL);
 }
 
 static void
-vips_foreign_load_png_file_init( VipsForeignLoadPngFile *file )
+vips_foreign_load_png_file_init(VipsForeignLoadPngFile *file)
 {
 }
 
@@ -339,46 +336,46 @@ typedef struct _VipsForeignLoadPngBuffer {
 
 typedef VipsForeignLoadPngClass VipsForeignLoadPngBufferClass;
 
-G_DEFINE_TYPE( VipsForeignLoadPngBuffer, vips_foreign_load_png_buffer, 
-	vips_foreign_load_png_get_type() );
+G_DEFINE_TYPE(VipsForeignLoadPngBuffer, vips_foreign_load_png_buffer,
+	vips_foreign_load_png_get_type());
 
 static int
-vips_foreign_load_png_buffer_build( VipsObject *object )
+vips_foreign_load_png_buffer_build(VipsObject *object)
 {
 	VipsForeignLoadPng *png = (VipsForeignLoadPng *) object;
 	VipsForeignLoadPngBuffer *buffer = (VipsForeignLoadPngBuffer *) object;
 
-	if( buffer->blob &&
-		!(png->source = vips_source_new_from_memory( 
-			VIPS_AREA( buffer->blob )->data, 
-			VIPS_AREA( buffer->blob )->length )) )
-		return( -1 );
+	if (buffer->blob &&
+		!(png->source = vips_source_new_from_memory(
+			  VIPS_AREA(buffer->blob)->data,
+			  VIPS_AREA(buffer->blob)->length)))
+		return -1;
 
-	if( VIPS_OBJECT_CLASS( vips_foreign_load_png_buffer_parent_class )->
-		build( object ) )
-		return( -1 );
+	if (VIPS_OBJECT_CLASS(vips_foreign_load_png_buffer_parent_class)
+			->build(object))
+		return -1;
 
-	return( 0 );
+	return 0;
 }
 
 static gboolean
-vips_foreign_load_png_buffer_is_a_buffer( const void *buf, size_t len )
+vips_foreign_load_png_buffer_is_a_buffer(const void *buf, size_t len)
 {
 	VipsSource *source;
 	gboolean result;
 
-	if( !(source = vips_source_new_from_memory( buf, len )) )
-		return( FALSE );
-	result = vips_foreign_load_png_source_is_a_source( source );
-	VIPS_UNREF( source );
+	if (!(source = vips_source_new_from_memory(buf, len)))
+		return FALSE;
+	result = vips_foreign_load_png_source_is_a_source(source);
+	VIPS_UNREF(source);
 
-	return( result );
+	return result;
 }
 
 static void
-vips_foreign_load_png_buffer_class_init( VipsForeignLoadPngBufferClass *class )
+vips_foreign_load_png_buffer_class_init(VipsForeignLoadPngBufferClass *class)
 {
-	GObjectClass *gobject_class = G_OBJECT_CLASS( class );
+	GObjectClass *gobject_class = G_OBJECT_CLASS(class);
 	VipsObjectClass *object_class = (VipsObjectClass *) class;
 	VipsForeignLoadClass *load_class = (VipsForeignLoadClass *) class;
 
@@ -386,26 +383,25 @@ vips_foreign_load_png_buffer_class_init( VipsForeignLoadPngBufferClass *class )
 	gobject_class->get_property = vips_object_get_property;
 
 	object_class->nickname = "pngload_buffer";
-	object_class->description = _( "load png from buffer" );
+	object_class->description = _("load png from buffer");
 	object_class->build = vips_foreign_load_png_buffer_build;
 
 	load_class->is_a_buffer = vips_foreign_load_png_buffer_is_a_buffer;
 
-	VIPS_ARG_BOXED( class, "buffer", 1, 
-		_( "Buffer" ),
-		_( "Buffer to load from" ),
-		VIPS_ARGUMENT_REQUIRED_INPUT, 
-		G_STRUCT_OFFSET( VipsForeignLoadPngBuffer, blob ),
-		VIPS_TYPE_BLOB );
-
+	VIPS_ARG_BOXED(class, "buffer", 1,
+		_("Buffer"),
+		_("Buffer to load from"),
+		VIPS_ARGUMENT_REQUIRED_INPUT,
+		G_STRUCT_OFFSET(VipsForeignLoadPngBuffer, blob),
+		VIPS_TYPE_BLOB);
 }
 
 static void
-vips_foreign_load_png_buffer_init( VipsForeignLoadPngBuffer *buffer )
+vips_foreign_load_png_buffer_init(VipsForeignLoadPngBuffer *buffer)
 {
 }
 
-#endif /*defined(HAVE_PNG) && !defined(HAVE_SPNG)*/
+#endif /*HAVE_PNG*/
 
 /**
  * vips_pngload:
@@ -427,8 +423,8 @@ vips_foreign_load_png_buffer_init( VipsForeignLoadPngBuffer *buffer )
  * Use @fail_on to set the type of error that will cause load to fail. By
  * default, loaders are permissive, that is, #VIPS_FAIL_ON_NONE.
  *
- * By default, the PNG loader limits the number of text and data chunks to 
- * block some denial of service attacks. Set @unlimited to disable these 
+ * By default, the PNG loader limits the number of text and data chunks to
+ * block some denial of service attacks. Set @unlimited to disable these
  * limits.
  *
  * See also: vips_image_new_from_file().
@@ -436,16 +432,16 @@ vips_foreign_load_png_buffer_init( VipsForeignLoadPngBuffer *buffer )
  * Returns: 0 on success, -1 on error.
  */
 int
-vips_pngload( const char *filename, VipsImage **out, ... )
+vips_pngload(const char *filename, VipsImage **out, ...)
 {
 	va_list ap;
 	int result;
 
-	va_start( ap, out );
-	result = vips_call_split( "pngload", ap, filename, out );
-	va_end( ap );
+	va_start(ap, out);
+	result = vips_call_split("pngload", ap, filename, out);
+	va_end(ap);
 
-	return( result );
+	return result;
 }
 
 /**
@@ -462,15 +458,15 @@ vips_pngload( const char *filename, VipsImage **out, ... )
  *
  * Exactly as vips_pngload(), but read from a PNG-formatted memory block.
  *
- * You must not free the buffer while @out is active. The 
- * #VipsObject::postclose signal on @out is a good place to free. 
+ * You must not free the buffer while @out is active. The
+ * #VipsObject::postclose signal on @out is a good place to free.
  *
  * See also: vips_pngload().
  *
  * Returns: 0 on success, -1 on error.
  */
 int
-vips_pngload_buffer( void *buf, size_t len, VipsImage **out, ... )
+vips_pngload_buffer(void *buf, size_t len, VipsImage **out, ...)
 {
 	va_list ap;
 	VipsBlob *blob;
@@ -478,15 +474,15 @@ vips_pngload_buffer( void *buf, size_t len, VipsImage **out, ... )
 
 	/* We don't take a copy of the data or free it.
 	 */
-	blob = vips_blob_new( NULL, buf, len );
+	blob = vips_blob_new(NULL, buf, len);
 
-	va_start( ap, out );
-	result = vips_call_split( "pngload_buffer", ap, blob, out );
-	va_end( ap );
+	va_start(ap, out);
+	result = vips_call_split("pngload_buffer", ap, blob, out);
+	va_end(ap);
 
-	vips_area_unref( VIPS_AREA( blob ) );
+	vips_area_unref(VIPS_AREA(blob));
 
-	return( result );
+	return result;
 }
 
 /**
@@ -500,21 +496,21 @@ vips_pngload_buffer( void *buf, size_t len, VipsImage **out, ... )
  * * @fail_on: #VipsFailOn, types of read error to fail on
  * * @unlimited: %gboolean, Remove all denial of service limits
  *
- * Exactly as vips_pngload(), but read from a source. 
+ * Exactly as vips_pngload(), but read from a source.
  *
  * See also: vips_pngload().
  *
  * Returns: 0 on success, -1 on error.
  */
 int
-vips_pngload_source( VipsSource *source, VipsImage **out, ... )
+vips_pngload_source(VipsSource *source, VipsImage **out, ...)
 {
 	va_list ap;
 	int result;
 
-	va_start( ap, out );
-	result = vips_call_split( "pngload_source", ap, source, out );
-	va_end( ap );
+	va_start(ap, out);
+	result = vips_call_split("pngload_source", ap, source, out);
+	va_end(ap);
 
-	return( result );
+	return result;
 }
