@@ -367,7 +367,7 @@ struct _Wtiff {
 	int rgbjpeg;					/* True for RGB not YCbCr */
 	int properties;					/* Set to save XML props */
 	VipsRegionShrink region_shrink; /* How to shrink regions */
-	int level;						/* zstd compression level */
+	int level;						/* Deflate (zlib) / zstd compression level */
 	gboolean lossless;				/* lossless mode */
 	VipsForeignDzDepth depth;		/* Pyr depth */
 	gboolean subifd;				/* Write pyr layers into subifds */
@@ -504,6 +504,9 @@ wtiff_layer_init(Wtiff *wtiff, Layer **layer, Layer *above,
 			break;
 
 		default:
+			// stop a compiler warning
+			limitw = 128;
+			limith = 128;
 			g_assert_not_reached();
 		}
 
@@ -513,8 +516,7 @@ wtiff_layer_init(Wtiff *wtiff, Layer **layer, Layer *above,
 		 * Very tall or wide images might end up with a smallest layer
 		 * larger than one tile.
 		 */
-		if (((*layer)->width > limitw ||
-				(*layer)->height > limith) &&
+		if (((*layer)->width > limitw || (*layer)->height > limith) &&
 			(*layer)->width > 1 &&
 			(*layer)->height > 1)
 			wtiff_layer_init(wtiff, &(*layer)->below, *layer,
@@ -660,9 +662,8 @@ wtiff_compress_jpeg_header(Wtiff *wtiff,
 	cinfo->input_components = image->Bands;
 
 	if (image->Bands == 4 &&
-		image->Type == VIPS_INTERPRETATION_CMYK) {
+		image->Type == VIPS_INTERPRETATION_CMYK)
 		space = JCS_CMYK;
-	}
 	else if (image->Bands == 3)
 		space = JCS_RGB;
 	else if (image->Bands == 1)
@@ -683,14 +684,32 @@ wtiff_compress_jpeg_header(Wtiff *wtiff,
 
 	jpeg_set_defaults(cinfo);
 
-	// use RGB mode (no chroma subsample) for high Q
-	if (wtiff->Q >= 90)
-		jpeg_set_colorspace(cinfo, JCS_RGB);
-
-	/* Set compression quality. Must be called after setting params above.
+	/* Set compression quality.
 	 */
 	jpeg_set_quality(cinfo, wtiff->Q, TRUE);
 
+	/* We must set chroma subsampling explicitly since some libjpegs do not
+	 * enable this by default.
+	 */
+	if (image->Bands == 3 &&
+		wtiff->Q < 90)
+		cinfo->comp_info[0].h_samp_factor = cinfo->comp_info[0].v_samp_factor = 2;
+	else
+		cinfo->comp_info[0].h_samp_factor = cinfo->comp_info[0].v_samp_factor = 1;
+
+	/* Rest should have sampling factors 1,1.
+	 */
+	for (int i = 1; i < image->Bands; i++)
+		cinfo->comp_info[i].h_samp_factor = cinfo->comp_info[i].v_samp_factor = 1;
+
+	/* For low Q, we write YCbCr, for high Q, RGB. The jpeg coeffs don't
+	 * encode the photometric interpretation, the tiff header does that,
+	 * so this code must be kept synced with wtiff_write_header().
+	 */
+	if (image->Bands == 3 &&
+		wtiff->Q >= 90)
+		jpeg_set_colorspace(cinfo, JCS_RGB);
+
 	// Avoid writing the JFIF APP0 marker.
 	cinfo->write_JFIF_header = FALSE;
 }
@@ -713,6 +732,9 @@ wtiff_compress_jpeg(Wtiff *wtiff,
 
 	// we could have one of these per thread and reuse it for a small speedup
 	cinfo.err = jpeg_std_error(&eman.pub);
+	cinfo.err->addon_message_table = vips__jpeg_message_table;
+	cinfo.err->first_addon_message = 1000;
+	cinfo.err->last_addon_message = 1001;
 	cinfo.dest = NULL;
 	eman.pub.error_exit = vips__new_error_exit;
 	eman.pub.output_message = vips__new_output_message;
@@ -721,7 +743,7 @@ wtiff_compress_jpeg(Wtiff *wtiff,
 	// we need a line buffer to pad edge tiles
 	line = VIPS_MALLOC(NULL, wtiff->tilew * sizeof_pel);
 
-	/* Error handling. The error message will have ben set by our handlers.
+	/* Error handling. The error message will have been set by our handlers.
 	 */
 	if (setjmp(eman.jmp)) {
 		jpeg_destroy_compress(&cinfo);
@@ -786,6 +808,9 @@ wtiff_compress_jpeg_tables(Wtiff *wtiff,
 	struct jpeg_error_mgr jerr;
 
 	cinfo.err = jpeg_std_error(&jerr);
+	cinfo.err->addon_message_table = vips__jpeg_message_table;
+	cinfo.err->first_addon_message = 1000;
+	cinfo.err->last_addon_message = 1001;
 	jpeg_create_compress(&cinfo);
 
 	/* Attach output.
@@ -835,13 +860,19 @@ wtiff_write_header(Wtiff *wtiff, Layer *layer)
 		TIFFSetField(tif, TIFFTAG_WEBP_LOSSLESS, wtiff->lossless);
 	}
 	if (wtiff->compression == COMPRESSION_ZSTD) {
-		TIFFSetField(tif, TIFFTAG_ZSTD_LEVEL, wtiff->level);
+		// Set zstd compression level - only accept valid values (1-22)
+		if (wtiff->level)
+			TIFFSetField(tif, TIFFTAG_ZSTD_LEVEL, VIPS_CLIP(1, wtiff->level, 22));
 		if (wtiff->predictor != VIPS_FOREIGN_TIFF_PREDICTOR_NONE)
 			TIFFSetField(tif,
 				TIFFTAG_PREDICTOR, wtiff->predictor);
 	}
 #endif /*HAVE_TIFF_COMPRESSION_WEBP*/
 
+	// Set deflate (zlib) compression level - only accept valid values (1-9)
+	if (wtiff->compression == COMPRESSION_ADOBE_DEFLATE && wtiff->level)
+		TIFFSetField(tif, TIFFTAG_ZIPQUALITY, VIPS_CLIP(1, wtiff->level, 9));
+
 	if ((wtiff->compression == COMPRESSION_ADOBE_DEFLATE ||
 			wtiff->compression == COMPRESSION_LZW) &&
 		wtiff->predictor != VIPS_FOREIGN_TIFF_PREDICTOR_NONE)
@@ -916,9 +947,8 @@ wtiff_write_header(Wtiff *wtiff, Layer *layer)
 			wtiff->ready->Bands < 3) {
 			/* Mono or mono + alpha.
 			 */
-			photometric = wtiff->miniswhite
-				? PHOTOMETRIC_MINISWHITE
-				: PHOTOMETRIC_MINISBLACK;
+			photometric = wtiff->miniswhite ?
+				PHOTOMETRIC_MINISWHITE : PHOTOMETRIC_MINISBLACK;
 			colour_bands = 1;
 		}
 		else if (wtiff->ready->Type == VIPS_INTERPRETATION_LAB ||
@@ -932,12 +962,10 @@ wtiff_write_header(Wtiff *wtiff, Layer *layer)
 			photometric = PHOTOMETRIC_LOGLUV;
 			/* Tell libtiff we will write as float XYZ.
 			 */
-			TIFFSetField(tif,
-				TIFFTAG_SGILOGDATAFMT, SGILOGDATAFMT_FLOAT);
+			TIFFSetField(tif, TIFFTAG_SGILOGDATAFMT, SGILOGDATAFMT_FLOAT);
 			stonits = 1.0;
 			if (vips_image_get_typeof(wtiff->ready, "stonits"))
-				vips_image_get_double(wtiff->ready,
-					"stonits", &stonits);
+				vips_image_get_double(wtiff->ready, "stonits", &stonits);
 			TIFFSetField(tif, TIFFTAG_STONITS, stonits);
 			colour_bands = 3;
 		}
@@ -956,8 +984,7 @@ wtiff_write_header(Wtiff *wtiff, Layer *layer)
 			 * that we will supply the image as YCbCr.
 			 */
 			photometric = PHOTOMETRIC_YCBCR;
-			TIFFSetField(tif, TIFFTAG_JPEGCOLORMODE,
-				JPEGCOLORMODE_RGB);
+			TIFFSetField(tif, TIFFTAG_JPEGCOLORMODE, JPEGCOLORMODE_RGB);
 			colour_bands = 3;
 		}
 		else {
@@ -983,11 +1010,9 @@ wtiff_write_header(Wtiff *wtiff, Layer *layer)
 			 * we are premultiplying.
 			 */
 			for (i = 0; i < alpha_bands; i++)
-				v[i] = i == 0 && wtiff->premultiply
-					? EXTRASAMPLE_ASSOCALPHA
-					: EXTRASAMPLE_UNASSALPHA;
-			TIFFSetField(tif,
-				TIFFTAG_EXTRASAMPLES, alpha_bands, v);
+				v[i] = i == 0 && wtiff->premultiply ?
+					EXTRASAMPLE_ASSOCALPHA : EXTRASAMPLE_UNASSALPHA;
+			TIFFSetField(tif, TIFFTAG_EXTRASAMPLES, alpha_bands, v);
 		}
 
 		TIFFSetField(tif, TIFFTAG_PHOTOMETRIC, photometric);
@@ -2319,6 +2344,7 @@ wtiff_copy_tiff(Wtiff *wtiff, TIFF *out, TIFF *in)
 	CopyField(TIFFTAG_TILELENGTH, ui32);
 	CopyField(TIFFTAG_ROWSPERSTRIP, ui32);
 	CopyField(TIFFTAG_SUBFILETYPE, ui32);
+	CopyField(TIFFTAG_PREDICTOR, ui16);
 
 	if (TIFFGetField(in, TIFFTAG_EXTRASAMPLES, &ui16, &a))
 		TIFFSetField(out, TIFFTAG_EXTRASAMPLES, ui16, a);
@@ -2331,8 +2357,8 @@ wtiff_copy_tiff(Wtiff *wtiff, TIFF *out, TIFF *in)
 	if (TIFFGetField(in, TIFFTAG_JPEGTABLES, &length, &buffer))
 		TIFFSetField(out, TIFFTAG_JPEGTABLES, length, buffer);
 
-	/* No need to set any of the pseudo tags that control compression since
-	 * we copy raw tiles.
+	/* Other compression tags are just pseudotags and don't need to be set
+	 * because we copy raw tiles.
 	 */
 
 	/* We can't copy profiles or xmp :( Set again from wtiff.
@@ -2372,8 +2398,7 @@ wtiff_gather(Wtiff *wtiff)
 			printf("appending layer sub = %d ...\n", layer->sub);
 #endif /*DEBUG*/
 
-			if (!(source =
-						vips_source_new_from_target(layer->target)))
+			if (!(source = vips_source_new_from_target(layer->target)))
 				return -1;
 
 			if (!(in = vips__tiff_openin_source(source))) {
